# CHANGELOG

### @TODO:
- improve the code
- change the interfaces and reimplement the callback method

## Version 0.1.7
- refactored all the code
- split the code in separate files
- added ProgressBar with threads and callback

## Version 0.1.6
- change the mode how the versions are experimented
## Version 1.0.4
- modification on how the GTK is imported and version specified
## Version 1.0.3
- small modification on readme and another push to PyPi
## Version 1.0.1
- initial release
